@@ -21,7 +21,6 @@ from .core import GroupMixin
 from .cog import Cog
 from .view import StringView
 from .context import Context
-
 from .typedefs import Message
 
 
@@ -32,10 +31,12 @@ def _is_submodule(parent: str, child: str) -> bool:
     return parent == child or child.startswith(parent + ".")
 
 
+class _DefaultRepr:
+    def __repr__(self) -> str:
+        return '<none>'
 
 
-
-
+_default = _DefaultRepr()
 
 
 class Bot(GroupMixin, Client):
@@ -82,12 +83,7 @@ class Bot(GroupMixin, Client):
         This attribute does not carry over to groups. You must set it to every
         group if you require group commands to be case insensitive as well.
     description: :class:`str`
-        The content prefixed into the default help message.
-    help_command: Optional[:class:`.HelpCommand`]
-        The help command implementation to use. This can be dynamically
-        set at runtime. To remove the help command pass ``None``. For more
-        information on implementing a help command, see
-        :ref:`ext_commands_help_command`.
+
     owner_id: Optional[:class:`int`]
         The user ID that owns the bot. This is used by :meth:`.is_owner()`
         and checks that call this method.
@@ -123,12 +119,10 @@ class Bot(GroupMixin, Client):
         self.__extensions = {}
         self._checks = []
         self._check_once = []
-
         self._before_invoke = None
         self._after_invoke = None
 
 
-
         self.add_event_handler('friend_message', self.process_commands)
         self.add_event_handler('party_message', self.process_commands)
 
@@ -407,7 +401,7 @@ class Bot(GroupMixin, Client):
         if cog is None:
             return
 
-
+        
 
         cog._eject(self)
 
@@ -630,7 +624,7 @@ class Bot(GroupMixin, Client):
         """
         return types.MappingProxyType(self.__extensions)
 
-    
+
 
     async def get_prefix(self, message: Message) -> Any:
         """|coro|
