@@ -188,7 +188,6 @@ class Command(_BaseCommand):
         self.callback = coro
         self.enabled = kwargs.get('enabled', True)
 
-        
 
         self.brief = kwargs.get('brief')
         self.usage = kwargs.get('usage')
@@ -954,7 +953,16 @@ class Command(_BaseCommand):
         """
         return type(self.cog).__cog_name__ if self.cog is not None else None
 
-    
+    @property
+    def short_doc(self) -> str:
+        """:class:`str`: Gets the "short" documentation of a command.
+
+        By default, this is the :attr:`brief` attribute.
+        If that lookup leads to an empty string then the first line of the
+        :attr:`help` attribute is used instead.
+        """
+
+        return ''
 
     def _is_typing_optional(self, annotation: Any) -> bool:
         try:
