@@ -22,8 +22,6 @@ if TYPE_CHECKING:
 
 __all__ = (
     'Paginator',
-    'HelpCommand',
-    'FortniteHelpCommand',
 )
 
 _IS_ASCII = re.compile(r'^[\x00-\x7f]+$')
@@ -169,45 +167,8 @@ class Paginator:
         return fmt.format(self)
 
 
-def _not_overridden(func: MaybeCoro) -> MaybeCoro:
-    func.__fnpy_help_command_not_overridden__ = True
-    return func
 
 
-class _HelpCommandImpl(Command):
-    def __init__(self, inject: Command, *args: list, **kwargs: dict) -> None:
-        super().__init__(inject.command_callback, *args, **kwargs)
-        self._original = inject
-        self._injected = inject
-
-    async def prepare(self, ctx: Context) -> None:
-        self._injected = injected = self._original.copy()
-        injected.context = ctx
-        self.callback = injected.command_callback
-
-        error_handler = injected.help_command_error_handler
-        if not hasattr(error_handler, '__fnpy_help_command_not_overridden__'):
-            if self.cog is not None:
-                self.error_handler = self._error_handler_cog_implementation
-            else:
-                self.error_handler = error_handler
-
-        await super().prepare(ctx)
-
-    async def _parse_arguments(self, ctx: Context) -> None:
-        # Make the parser think we don't have a cog so it doesn't
-        # inject the parameter into `ctx.args`.
-        original_cog = self.cog
-        self.cog = None
-        try:
-            await super()._parse_arguments(ctx)
-        finally:
-            self.cog = original_cog
-
-    async def _error_handler_cog_implementation(self, _,
-                                                ctx: Context,
-                                                error: Exception) -> None:
-        await self._injected.help_command_error_handler(ctx, error)
 
     @property
     def clean_params(self) -> OrderedDict:
@@ -252,91 +213,6 @@ class _HelpCommandImpl(Command):
         self.cog = None
 
 
-class HelpCommand:
-    r"""The base implementation for help command formatting.
-
-    .. note::
-
-        Internally instances of this class are deep copied every time
-        the command itself is invoked to prevent a race condition
-        mentioned in discord.py issue 2123.
-
-        This means that relying on the state of this class to be
-        the same between command invocations would not work as expected.
-
-    Attributes
-    -----------
-    context: Optional[:class:`Context`]
-        The context that invoked this help formatter. This is generally set
-        after the help command assigned, :func:`command_callback`\, has been
-        called.
-    show_hidden: :class:`bool`
-        Specifies if hidden commands should be shown in the output.
-        Defaults to ``False``.
-    verify_checks: :class:`bool`
-        Specifies if commands should have their :attr:`.Command.checks` called
-        and verified. Defaults to ``True``.
-    command_attrs: :class:`dict`
-        A dictionary of options to pass in for the construction of the help
-        command. This allows you to change the command behaviour without
-        actually changing the implementation of the command. The attributes
-        will be the same as the ones passed in the :class:`.Command`
-        constructor.
-    """
-
-    def __new__(cls, *args: list, **kwargs: dict) -> 'HelpCommand':
-        # To prevent race conditions of a single instance while also allowing
-        # for settings to be passed the original arguments passed must be
-        # assigned to allow for easier copies (which will be made when the
-        # help command is actually called)
-        # see discord.py issue 2123
-        self = super().__new__(cls)
-
-        # Shallow copies cannot be used in this case since it is not unusual
-        # to pass instances that need state, e.g. Paginator or what have you
-        # into the function. The keys can be safely copied as-is since they're
-        # 99.99% certain of being string keys
-        deepcopy = copy.deepcopy
-        self.__original_kwargs__ = {
-            k: deepcopy(v)
-            for k, v in kwargs.items()
-        }
-        self.__original_args__ = deepcopy(args)
-        return self
-
-    def __init__(self, **options: dict) -> None:
-        self.show_hidden = options.pop('show_hidden', False)
-        self.verify_checks = options.pop('verify_checks', True)
-        self.command_attrs = attrs = options.pop('command_attrs', {})
-        attrs.setdefault('name', 'help')
-        attrs.setdefault('help', 'Shows this message')
-        self.context = None
-        self._command_impl = None
-
-    def copy(self) -> 'HelpCommand':
-        o = self.__class__(*self.__original_args__, **self.__original_kwargs__)
-        o._command_impl = self._command_impl
-        return o
-
-    def _add_to_bot(self, bot: 'Bot') -> None:
-        command = _HelpCommandImpl(self, **self.command_attrs)
-        bot.add_command(command)
-        self._command_impl = command
-
-    def _remove_from_bot(self, bot: 'Bot') -> None:
-        bot.remove_command(self._command_impl.name)
-        self._command_impl._eject_cog()
-        self._command_impl = None
-
-    def get_bot_mapping(self) -> Dict[Optional[Cog], List[Command]]:
-        """Retrieves the bot mapping passed to :meth:`send_bot_help`."""
-        bot = self.context.bot
-        mapping = {
-            cog: cog.get_commands()
-            for cog in bot.cogs.values()
-        }
-        mapping[None] = [c for c in bot.all_commands.values() if c.cog is None]
-        return mapping
 
     @property
     def command_prefix(self) -> str:
