@@ -3,7 +3,7 @@
 """
 MIT License
 
-Copyright (c) 2019-2020 Terbau
+Copyright (c) 2019-2021 Terbau
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -30,11 +30,12 @@ import logging
 import json
 import re
 import time
+import functools
 
 from typing import TYPE_CHECKING, List, Optional, Any, Union, Tuple
 from urllib.parse import quote
-from .utils import MaybeLock
 
+from .utils import MaybeLock
 from .errors import HTTPException
 
 if TYPE_CHECKING:
@@ -323,6 +324,59 @@ class StatsproxyPublicService(Route):
     AUTH = 'FORTNITE_ACCESS_TOKEN'
 
 
+def create_aiohttp_closed_event(session) -> asyncio.Event:
+    """Work around aiohttp issue that doesn't properly close transports on exit.
+
+    See https://github.com/aio-libs/aiohttp/issues/1925#issuecomment-639080209
+
+    Returns:
+       An event that will be set once all transports have been properly closed.
+    """
+
+    transports = 0
+    all_is_lost = asyncio.Event()
+
+    def connection_lost(exc, orig_lost):
+        nonlocal transports
+
+        try:
+            orig_lost(exc)
+        finally:
+            transports -= 1
+            if transports == 0:
+                all_is_lost.set()
+
+    def eof_received(orig_eof_received):
+        try:
+            orig_eof_received()
+        except AttributeError:
+            # It may happen that eof_received() is called after
+            # _app_protocol and _transport are set to None.
+            pass
+
+    for conn in session.connector._conns.values():
+        for handler, _ in conn:
+            proto = getattr(handler.transport, "_ssl_protocol", None)
+            if proto is None:
+                continue
+
+            transports += 1
+            orig_lost = proto.connection_lost
+            orig_eof_received = proto.eof_received
+
+            proto.connection_lost = functools.partial(
+                connection_lost, orig_lost=orig_lost
+            )
+            proto.eof_received = functools.partial(
+                eof_received, orig_eof_received=orig_eof_received
+            )
+
+    if transports == 0:
+        all_is_lost.set()
+
+    return all_is_lost
+
+
 class HTTPClient:
     def __init__(self, client: 'Client', *,
                  connector: aiohttp.BaseConnector = None,
@@ -377,7 +431,9 @@ class HTTPClient:
     async def close(self) -> None:
         self._jar.clear()
         if self.__session:
+            event = create_aiohttp_closed_event(self.__session)
             await self.__session.close()
+            await event.wait()
 
     def create_connection(self) -> None:
         self.__session = aiohttp.ClientSession(
