@@ -3,7 +3,7 @@
 """
 MIT License
 
-Copyright (c) 2019-2020 Terbau
+Copyright (c) 2019-2021 Terbau
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -28,12 +28,13 @@ import logging
 
 from aioxmpp import JID
 from typing import TYPE_CHECKING, Any, List, Optional
-from .enums import ProfileSearchPlatform, ProfileSearchMatchType
+from .enums import UserSearchPlatform, UserSearchMatchType, StatsCollectionType
 from .typedefs import DatetimeOrTimestamp
+from .errors import Forbidden
 
 if TYPE_CHECKING:
     from .client import Client
-    from .stats import StatsV2
+    from .stats import StatsV2, StatsCollection
 
 log = logging.getLogger(__name__)
 
@@ -87,6 +88,12 @@ class ExternalAuth:
                 'external_display_name={0.external_display_name!r} '
                 'external_id={0.external_id!r}>'.format(self))
 
+    def __eq__(self, other):
+        return isinstance(other, ExternalAuth) and other.id == self.id
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def get_raw(self) -> dict:
         return {
             'type': self.type,
@@ -109,15 +116,26 @@ class UserBase:
     def __str__(self) -> str:
         return self.display_name
 
+    def __eq__(self, other):
+        return isinstance(other, UserBase) and other._id == self._id
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     @property
-    def display_name(self) -> str:
-        """:class:`str`: The users displayname
+    def display_name(self) -> Optional[str]:
+        """Optional[:class:`str`]: The users displayname
 
         .. warning::
 
             The display name will be the one registered to the epicgames
             account. If an epicgames account is not found it defaults
             to the display name of an external auth.
+
+        .. warning::
+
+            This property might be ``None`` if
+            ``Client.fetch_user_data_in_events`` is set to ``False``.
         """
         return self._epicgames_display_name or self._external_display_name
 
@@ -145,6 +163,12 @@ class UserBase:
             If this is True, the display name will be the one registered to
             the epicgames account, if not it defaults to the display name of
             an external auth.
+
+        .. warning::
+
+            This property might be ``False`` even though the account is a
+            registered epic games account if
+            ``Client.fetch_user_data_in_events`` is set to ``False``.
         """
         return self._epicgames_display_name is not None
 
@@ -153,6 +177,26 @@ class UserBase:
         """:class:`aioxmpp.JID`: The JID of the user."""
         return JID.fromstr('{0.id}@{0.client.service_host}'.format(self))
 
+    async def fetch(self) -> None:
+        """|coro|
+
+        Fetches basic information about this user and sets the updated
+        properties. This might be useful if you for example need to be
+        sure the display name is updated or if you have
+        ``Client.fetch_user_data_in_events`` set to ``False``.
+
+        Raises
+        ------
+        HTTPException
+            An error occured while requesting.
+        """
+        result = await self.client.http.account_graphql_get_multiple_by_user_id(  # noqa
+            (self.id,),
+        )
+        data = result['accounts'][0]
+
+        self._update(data)
+
     async def fetch_br_stats(self, *,
                              start_time: Optional[DatetimeOrTimestamp] = None,
                              end_time: Optional[DatetimeOrTimestamp] = None
@@ -175,9 +219,9 @@ class UserBase:
         Raises
         ------
         Forbidden
-            | The user has chosen to be hidden from public stats by disabling
+            The user has chosen to be hidden from public stats by disabling
             the fortnite setting below.
-            |  ``Settings`` -> ``Account and Privacy`` -> ``Show on career
+            ``Settings`` -> ``Account and Privacy`` -> ``Show on career
             leaderboard``
         HTTPException
             An error occured while requesting.
@@ -193,7 +237,54 @@ class UserBase:
             end_time=end_time
         )
 
+    async def fetch_br_stats_collection(self, collection: StatsCollectionType,
+                                        start_time: Optional[DatetimeOrTimestamp] = None,  # noqa
+                                        end_time: Optional[DatetimeOrTimestamp] = None  # noqa)
+                                        ) -> 'StatsCollection':
+        """|coro|
+
+        Fetches a stats collections for this user.
+
+        Parameters
+        ----------
+        start_time: Optional[Union[:class:`int`, :class:`datetime.datetime`, :class:`SeasonStartTimestamp`]]
+            The UTC start time of the time period to get stats from.
+            *Must be seconds since epoch, :class:`datetime.datetime` or a constant from SeasonEndTimestamp*
+            *Defaults to None*
+        end_time: Optional[Union[:class:`int`, :class:`datetime.datetime`, :class:`SeasonEndTimestamp`]]
+            The UTC end time of the time period to get stats from.
+            *Must be seconds since epoch, :class:`datetime.datetime` or a constant from SeasonEndTimestamp*
+            *Defaults to None*
+
+        Raises
+        ------
+        Forbidden
+            The user has chosen to be hidden from public stats by disabling
+            the fortnite setting below.
+            ``Settings`` -> ``Account and Privacy`` -> ``Show on career
+            leaderboard``
+        HTTPException
+            An error occured while requesting.
+
+        Returns
+        -------
+        :class:`StatsCollection`
+            An object representing the stats collection for this user.
+        """  # noqa
+        res = await self.client.fetch_multiple_br_stats_collections(
+            user_ids=(self.id,),
+            collection=collection,
+            start_time=start_time,
+            end_time=end_time,
+        )
+
+        if self.id not in res:
+            raise Forbidden('User has opted out of public leaderboards.')
+
+        return res[self.id]
+
     async def fetch_battlepass_level(self, *,
+                                     season: int,
                                      start_time: Optional[DatetimeOrTimestamp] = None,  # noqa
                                      end_time: Optional[DatetimeOrTimestamp] = None  # noqa
                                      ) -> float:
@@ -203,6 +294,14 @@ class UserBase:
 
         Parameters
         ----------
+        season: :class:`int`
+            The season number to request the battlepass level for.
+            
+            .. warning::
+
+                If you are requesting the previous season and the new season has not been
+                added to the library yet (check :class:`SeasonStartTimestamp`), you have to
+                manually include the previous seasons end timestamp in epoch seconds.
         start_time: Optional[Union[:class:`int`, :class:`datetime.datetime`, :class:`SeasonStartTimestamp`]]
             The UTC start time of the window to get the battlepass level from.
             *Must be seconds since epoch, :class:`datetime.datetime` or a constant from SeasonEndTimestamp*
@@ -212,11 +311,6 @@ class UserBase:
             *Must be seconds since epoch, :class:`datetime.datetime` or a constant from SeasonEndTimestamp*
             *Defaults to None*
 
-        .. note::
-
-            If neither start_time nor end_time is ``None`` (default), then
-            the battlepass level from the current season is fetched.
-
         Raises
         ------
         HTTPException
@@ -224,12 +318,18 @@ class UserBase:
 
         Returns
         -------
-        :class:`float`
+        Optional[:class:`float`]
             The users battlepass level. ``None`` is returned if the user has
             not played any real matches this season.
+
+            .. note::
+
+                The decimals are the percent progress to the next level.
+                E.g. ``208.63`` -> ``Level 208 and 63% on the way to 209.``
         """  # noqa
         return await self.client.fetch_battlepass_level(
             self.id,
+            season=season,
             start_time=start_time,
             end_time=end_time
         )
@@ -242,8 +342,7 @@ class UserBase:
             extra_external_auths=data.get('extraExternalAuths', []),
         )
 
-        self._id = data.get('accountId',
-                            data.get('id', data.get('account_id')))
+        self._id = data.get('id', data.get('accountId', data.get('account_id')))  # noqa
 
     def _update_external_auths(self, external_auths: List[dict], *,
                                extra_external_auths: List[dict] = []) -> None:
@@ -395,6 +494,40 @@ class User(UserBase):
         """
         await self.client.block_user(self.id)
 
+    async def add(self) -> None:
+        """|coro|
+
+        Sends a friendship request to this user or adds them if they
+        have already sent one to the client.
+
+        Raises
+        ------
+        NotFound
+            The specified user does not exist.
+        DuplicateFriendship
+            The client is already friends with this user.
+        FriendshipRequestAlreadySent
+            The client has already sent a friendship request that has not been
+            handled yet by the user.
+        MaxFriendshipsExceeded
+            The client has hit the max amount of friendships a user can
+            have at a time. For most accounts this limit is set to ``1000``
+            but it could be higher for others.
+        InviteeMaxFriendshipsExceeded
+            The user you attempted to add has hit the max amount of friendships
+            a user can have at a time.
+        InviteeMaxFriendshipRequestsExceeded
+            The user you attempted to add has hit the max amount of friendship
+            requests a user can have at a time. This is usually ``700`` total
+            requests.
+        Forbidden
+            The client is not allowed to send friendship requests to the user
+            because of the users settings.
+        HTTPException
+            An error occured while requesting to add this friend.
+        """
+        await self.client.add_friend(self.id)
+
 
 class BlockedUser(UserBase):
     """Represents a blocked user from Fortnite"""
@@ -417,35 +550,35 @@ class BlockedUser(UserBase):
         await self.client.unblock_user(self.id)
 
 
-class ProfileSearchEntryUser(User):
-    """Represents a user entry in a profile search.
+class UserSearchEntry(User):
+    """Represents a user entry in a user search.
 
     Parameters
     ----------
-    matches: List[Tuple[:class:`str`, :class:`ProfileSearchPlatform`]]
+    matches: List[Tuple[:class:`str`, :class:`UserSearchPlatform`]]
         | A list of tuples containing the display name the user matched
         and the platform the display name is from.
-        | Example: ``[('Tfue', ProfileSearchPlatform.EPIC_GAMES)]``
-    match_type: :class:`ProfileSearchMatchType`
+        | Example: ``[('Tfue', UserSearchPlatform.EPIC_GAMES)]``
+    match_type: :class:`UserSearchMatchType`
         The type of match this user matched by.
     mutual_friend_count: :class:`int`
         The amount of **epic** mutual friends the client has with the user.
     """
     def __init__(self, client: 'Client',
-                 profile_data: dict,
+                 user_data: dict,
                  search_data: dict) -> None:
-        super().__init__(client, profile_data)
+        super().__init__(client, user_data)
 
-        self.matches = [(d['value'], ProfileSearchPlatform(d['platform']))
+        self.matches = [(d['value'], UserSearchPlatform(d['platform']))
                         for d in search_data['matches']]
-        self.match_type = ProfileSearchMatchType(search_data['matchType'])
+        self.match_type = UserSearchMatchType(search_data['matchType'])
         self.mutual_friend_count = search_data['epicMutuals']
 
     def __str__(self) -> str:
         return self.matches[0][0]
 
     def __repr__(self) -> str:
-        return ('<ProfileSearchEntryUser id={0.id!r} '
+        return ('<UserSearchEntry id={0.id!r} '
                 'display_name={0.display_name!r} '
                 'epicgames_account={0.epicgames_account!r}>'.format(self))
 
@@ -463,9 +596,9 @@ class SacSearchEntryUser(User):
         Wether or not the creator code is verified or not.
     """
     def __init__(self, client: 'Client',
-                 profile_data: dict,
+                 user_data: dict,
                  search_data: dict) -> None:
-        super().__init__(client, profile_data)
+        super().__init__(client, user_data)
 
         self.slug = search_data['slug']
         self.active = search_data['status'] == 'ACTIVE'
